pub enum GExiv2Metadata {}Expand description
An opaque structure that serves as a container for a media file’s metadata.
You can only create one via gexiv2_metadata_new().
Be sure to free it after use with gexiv2_metadata_free().